package de.ronnyfriedland.cassandra.entity;

import java.util.UUID;

/**
 * Basis Entity für Cassandra
 * 
 * @author Ronny Friedland
 */
public class BaseEntity {

    private String uuid;
    private String columnFamily;
    private long creationTime;

    /**
     * Erzeugt eine neue BaseEntity-Instanz.
     */
    protected BaseEntity() {
        super();
    }

    /**
     * Erzeugt eine neue BaseEntity-Instanz.
     * 
     * @param aColumnFamily
     */
    public BaseEntity(final String aColumnFamily) {
        uuid = UUID.randomUUID().toString();
        columnFamily = aColumnFamily;
    }

    /**
     * Erzeugt eine neue BaseEntity-Instanz.
     * 
     * @param aUuid
     * @param aColumnFamily
     */
    public BaseEntity(final String aUuid, final String aColumnFamily) {
        uuid = aUuid;
        columnFamily = aColumnFamily;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(final String uuid) {
        this.uuid = uuid;
    }

    public void setColumnFamily(final String columnFamily) {
        this.columnFamily = columnFamily;
    }

    public String getColumnFamily() {
        return columnFamily;
    }

    public void setCreationTime(final long creationTime) {
        this.creationTime = creationTime;
    }

    public long getCreationTime() {
        return creationTime;
    }

    /**
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuffer sbuf = new StringBuffer(super.toString());
        sbuf.append(String.format("[uuid: %s]", getUuid()));
        sbuf.append(String.format("[columnFamily: %s]", getColumnFamily()));
        sbuf.append(String.format("[creationTime: %d]", getCreationTime()));
        return sbuf.toString();
    }
}
