package de.ronnyfriedland.cassandra.props;

import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * @author Ronny Friedland
 */
public class CassandraProperties {
    private static final Logger LOG = Logger.getLogger(CassandraProperties.class.getName());
    private static final Properties PROPS = new Properties();
    private static final String PROPS_FILENAME = "cassandra.properties";

    static {
        try {
            PROPS.load(Thread.currentThread().getContextClassLoader().getResourceAsStream("cassandra.properties"));
            if (LOG.isLoggable(Level.INFO)) {
                LOG.info(String.format("Successfully loaded property file \"%1$s\".", PROPS_FILENAME));
            }
        } catch (Exception e) {
            LOG.log(Level.WARNING,
                    String.format("Error loading properties \"%1$s\" - using defaults.", PROPS_FILENAME), e);
        }
    }

    /**
     * Erzeugt eine neue CassandraProperties-Instanz.
     */
    private CassandraProperties() {
        // empty
    }

    /**
     * Liefert den Namen (inkl. Pfad) des Keystores.
     * 
     * @return Name/Pfad des Keystores
     */
    public static String getKeystoreName() {
        return PROPS.getProperty("sec.keystore", "keystore.jks");
    }

    /**
     * Liefert das Passwort für den Keystore.
     * 
     * @return Keytore-Passwort
     */
    public static char[] getKeystorePassword() {
        return PROPS.getProperty("sec.keystore.password", "cassandra#api#1").toCharArray();
    }

    /**
     * Liefert den Alias für den Schlüsseleintrag im Keystore.
     * 
     * @return Alias für Schlüssel
     */
    public static String getKeyAlias() {
        return PROPS.getProperty("sec.keystore.key.alias", "caspriv");
    }

    /**
     * Liefert das Passwort für den privaten Schlüssel
     * 
     * @return Passwort für privaten Schlüssel
     */
    public static char[] getKeyPassword() {
        return PROPS.getProperty("sec.keystore.key.password", "cassandra#api#1").toCharArray();
    }

}
