package de.ronnyfriedland.cassandra;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import de.ronnyfriedland.cassandra.api.CassandraClient;
import de.ronnyfriedland.cassandra.api.SecureCassandraClient;
import de.ronnyfriedland.cassandra.entity.BaseEntity;
import de.ronnyfriedland.cassandra.entity.SecureBaseEntity;
import de.ronnyfriedland.cassandra.sec.SecurityUtils;

public class ApiClientTest {

    private CassandraClient client;
    private SecureCassandraClient secureClient;

    @Before
    public void setUp() throws Exception {
        client = new CassandraClient("192.168.8.5", 9160, "PLAYGROUND");
        secureClient = new SecureCassandraClient("192.168.8.5", 9160, "PLAYGROUND");
    }

    @After
    public void tearDown() throws Exception {
        client.close();
    }

    @Test
    public void testCRUD() throws Exception {
        BaseEntity entity = new BaseEntity("User");

        String uuid = entity.getUuid();
        client.insert(entity);

        BaseEntity entity2 = client.select(entity.getUuid(), entity.getColumnFamily());
        Assert.assertEquals(uuid, entity.getUuid());

        client.remove(entity2);
    }

    @Test
    public void testSecurityCRUD() throws Exception {
        SecureBaseEntity entity = new SecureBaseEntity("User", new SecurityUtils().getSecretKey().getEncoded());

        String uuid = entity.getUuid();
        secureClient.insert(entity);

        BaseEntity entity2 = secureClient.select(entity.getUuid(), entity.getColumnFamily());
        Assert.assertEquals(uuid, entity.getUuid());

        secureClient.remove(entity2);
    }
}
