package de.ronnyfriedland.cassandra;

import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.util.List;
import java.util.UUID;

import org.apache.cassandra.thrift.Cassandra;
import org.apache.cassandra.thrift.Column;
import org.apache.cassandra.thrift.ColumnOrSuperColumn;
import org.apache.cassandra.thrift.ColumnParent;
import org.apache.cassandra.thrift.ColumnPath;
import org.apache.cassandra.thrift.ConsistencyLevel;
import org.apache.cassandra.thrift.InvalidRequestException;
import org.apache.cassandra.thrift.SlicePredicate;
import org.apache.cassandra.thrift.SliceRange;
import org.apache.cassandra.thrift.TimedOutException;
import org.apache.cassandra.thrift.UnavailableException;
import org.apache.thrift.TException;
import org.apache.thrift.protocol.TBinaryProtocol;
import org.apache.thrift.transport.TFramedTransport;
import org.apache.thrift.transport.TSocket;
import org.apache.thrift.transport.TTransport;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class CRUDTest {

    private TTransport transport;
    private Cassandra.Client client;

    private final String ENCODING = "UTF-8";
    private final String KEYSPACE = "PLAYGROUND";
    private final String CF = "User";

    @Before
    public void setUp() throws Exception {
        // Verbindung aufbauen
        transport = new TFramedTransport(new TSocket("192.168.8.5", 9160));
        client = new Cassandra.Client(new TBinaryProtocol(transport));
        transport.open();
        // Keyspace setzen, welcher f�r den Test genutzt wird.
        client.set_keyspace(KEYSPACE);
    }

    @After
    public void tearDown() throws Exception {
        // Verbindung schliessen
        transport.flush();
        transport.close();
    }

    @Test
    public void testCRUD() throws UnsupportedEncodingException, InvalidRequestException, UnavailableException,
            TimedOutException, TException {
        long currentTimeMillis = System.currentTimeMillis();
        final String id = String.valueOf(currentTimeMillis);
        final ColumnParent parent = new ColumnParent(CF);

        // Daten einfügen

        Column username = new Column(ByteBuffer.wrap("uuid".getBytes(ENCODING)), ByteBuffer.wrap(UUID.randomUUID()
                .toString().getBytes()), currentTimeMillis);

        ByteBuffer userid = ByteBuffer.wrap(id.getBytes(ENCODING));

        client.insert(userid, parent, username, ConsistencyLevel.ONE);

        // Daten abfragen

        SlicePredicate slicePredicate = new SlicePredicate();
        SliceRange sliceRange = new SliceRange();
        sliceRange.setStart(new byte[] {});
        sliceRange.setFinish(new byte[] {});
        slicePredicate.setSlice_range(sliceRange);

        List<ColumnOrSuperColumn> result = client.get_slice(ByteBuffer.wrap(id.getBytes(ENCODING)), parent,
                slicePredicate, ConsistencyLevel.ONE);

        Assert.assertFalse(result.isEmpty());
        Assert.assertTrue(1 == result.size());

        for (ColumnOrSuperColumn col : result) {
            Assert.assertNotNull(col.getColumn());

            String name = new String(col.getColumn().getName(), ENCODING);
            String value = new String(col.getColumn().getValue(), ENCODING);
            long timestamp = col.getColumn().getTimestamp();

            System.out.println("------------------------------");
            System.out.println(String.format("name: %s", name));
            System.out.println(String.format("value: %s", value));
            System.out.println(String.format("timestamp: %d", timestamp));
            System.out.println("------------------------------");
        }

        // Daten löschen

        ColumnPath path = new ColumnPath();
        path.column_family = CF;
        client.remove(ByteBuffer.wrap(id.getBytes(ENCODING)), path, currentTimeMillis, ConsistencyLevel.ONE);

        // Prüfung, ob keine Daten mehr vorhanden sind

        result = client.get_slice(ByteBuffer.wrap(id.getBytes(ENCODING)), parent, slicePredicate, ConsistencyLevel.ONE);

        Assert.assertTrue(result.isEmpty());
    }
}